Index: /trunk/src/VBox/Frontends/VirtualBox/src/extensions/QIManagerDialog.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/extensions/QIManagerDialog.h	(revision 86832)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/extensions/QIManagerDialog.h	(revision 86833)
@@ -126,6 +126,8 @@
         /** Defines the @a pWidget instance. */
         void setWidget(QWidget *pWidget) { m_pWidget = pWidget; }
-        /** Defines the @a pWidgetMenu instance. */
-        void setWidgetMenu(QMenu *pWidgetMenu) { m_pWidgetMenu = pWidgetMenu; }
+        /** Defines the reference to widget menu, replacing current one. */
+        void setWidgetMenu(QMenu *pWidgetMenu) { m_widgetMenus = QList<QMenu*>() << pWidgetMenu; }
+        /** Defines the list of references to widget menus, replacing current one. */
+        void setWidgetMenus(QList<QMenu*> widgetMenus) { m_widgetMenus = widgetMenus; }
 #ifdef VBOX_WS_MAC
         /** Defines the @a pWidgetToolbar instance. */
@@ -186,6 +188,7 @@
         QWidget *m_pWidget;
 
-        /** Holds the widget menu instance. */
-        QMenu     *m_pWidgetMenu;
+        /** Holds a list of widget menu references. */
+        QList<QMenu*> m_widgetMenus;
+
 #ifdef VBOX_WS_MAC
         /** Holds the widget toolbar instance. */

Index: /trunk/src/VBox/Frontends/VirtualBox/src/extensions/QIManagerDialog.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/extensions/QIManagerDialog.cpp	(revision 86832)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/extensions/QIManagerDialog.cpp	(revision 86833)
@@ -59,5 +59,4 @@
     , m_fCloseEmitted(false)
     , m_pWidget(0)
-    , m_pWidgetMenu(0)
 #ifdef VBOX_WS_MAC
     , m_pWidgetToolbar(0)
@@ -187,8 +186,11 @@
 void QIManagerDialog::prepareMenuBar()
 {
-    if (!m_pWidgetMenu)
+    /* Skip the call if there are no menus to add: */
+    if (m_widgetMenus.isEmpty())
         return;
-    /* Add widget menu: */
-    menuBar()->addMenu(m_pWidgetMenu);
+
+    /* Add all the widget menus: */
+    foreach (QMenu *pMenu, m_widgetMenus)
+        menuBar()->addMenu(pMenu);
 
 #ifdef VBOX_WS_MAC